pub struct Container<T>where
T: 'static,{ /* private fields */ }Expand description
A container for a value that can be observed.
The container is the basic implementation of a binding that holds a value and notifies watchers when the value changes.
Implementations