pub trait HandlerOnce<Args, T = ()>: 'static {
// Required method
fn call_once(self, env: &Environment) -> T;
}Expand description
A one-shot handler that can extract arguments from the environment.
Required Methods
Sourcefn call_once(self, env: &Environment) -> T
fn call_once(self, env: &Environment) -> T
Invokes the handler once using values extracted from env.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".