pub trait ViewBuilder: 'static {
type Output: View;
// Required method
fn build(&self) -> Self::Output;
}Expand description
A trait for types that can repeatedly construct views.
This is a convenience trait that provides similar functionality to Fn() -> impl View,
allowing types to be used as view factories.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".