ViewRenderer

Struct ViewRenderer 

pub struct ViewRenderer(/* private fields */);
Type-erased view renderer stored in Environment.

This wrapper allows storing the renderer in the Environment without exposing the concrete implementation type.

Implementations

Source

impl ViewRenderer

pub fn new<T: CustomViewRenderer>(renderer: T) -> Self

Create a new view renderer from a custom implementation.

pub async fn render(&self, view: AnyView, size: RenderSize) -> RenderResult

Render a view to RGBA pixel data.