pub struct ViewRenderer(/* private fields */);Expand description
Type-erased view renderer stored in Environment.
This wrapper allows storing the renderer in the Environment without exposing the concrete implementation type.
Implementations
Sourceimpl ViewRenderer
impl ViewRenderer
Sourcepub fn new<T: CustomViewRenderer>(renderer: T) -> Self
pub fn new<T: CustomViewRenderer>(renderer: T) -> Self
Create a new view renderer from a custom implementation.
Sourcepub async fn render(&self, view: AnyView, size: RenderSize) -> RenderResult
pub async fn render(&self, view: AnyView, size: RenderSize) -> RenderResult
Render a view to RGBA pixel data.