pub trait Interpolatable: Clone {
// Required method
fn lerp(&self, other: &Self, t: f32) -> Self;
}Expand description
Trait for types that can be linearly interpolated.
This is used by the animation system to interpolate between values. Most numeric types implement this automatically via the blanket impl.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".